@@ -27,6 +27,7 @@
 #include <string.h>
 #include <sys/stat.h>
 
+#include <libedataserver/e-data-server-util.h>
 #include <camel/camel-i18n.h>
 
 #include "camel-exchange-folder.h"
@@ -218,25 +219,23 @@ exchange_expunge (CamelFolder *folder, CamelException *ex)
 
 	if (!camel_exchange_store_connected (store, ex)) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
-				     _("This operation cannot be performed in off-line mode"));
+				     _("You cannot expunge in offline mode."));
 		return;
 	}
 
 	trash = camel_store_get_trash (folder->parent_store, NULL);
-	if (trash)
-		camel_object_unref (CAMEL_OBJECT (trash));
-	if (trash != folder) {
-		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
-				     _("Can only expunge in Deleted Items folder"));
+	if (!trash) {
+		printf ("Expunge failed, could not read trash folder\n");
 		return;
 	}
 
-	uids = camel_folder_get_uids (folder);
+	uids = camel_folder_get_uids (trash);
 	camel_stub_send (exch->stub, ex, CAMEL_STUB_CMD_EXPUNGE_UIDS,
-			 CAMEL_STUB_ARG_FOLDER, folder->full_name,
+			 CAMEL_STUB_ARG_FOLDER, trash->full_name,
 			 CAMEL_STUB_ARG_STRINGARRAY, uids,
 			 CAMEL_STUB_ARG_END);
-	camel_folder_free_uids (folder, uids);
+	camel_folder_free_uids (trash, uids);
+	camel_object_unref (CAMEL_OBJECT (trash));
 }
 
 static void
@@ -285,6 +284,33 @@ append_message (CamelFolder *folder, CamelMimeMessage *message,
 	CamelStream *stream_mem;
 	CamelExchangeStore *store = CAMEL_EXCHANGE_STORE (folder->parent_store);
 
+	char *old_subject = NULL;
+	GString *new_subject;
+	int i, len;
+
+	/* 
+	   FIXME: We should add a top-level camel API camel_mime_message_prune_invalid_chars 
+	   which each of the provider will have to implement to remove things 
+	   that are invalid for their Transport mechanism. This will help in 
+	   avoiding  duplication of work. Now Sending and Importing both requires
+	   substitution of \t and \n with blank. 
+	*/
+	
+	old_subject = g_strdup(camel_mime_message_get_subject (message));
+	
+	if (old_subject) {
+		len = strlen (old_subject);
+		new_subject = g_string_new("");
+		for (i = 0; i < len; i++) 
+			if ((old_subject[i] != '\t') && (old_subject[i] != '\n'))
+				new_subject = g_string_append_c (new_subject, old_subject[i]);
+			else
+				new_subject = g_string_append_c (new_subject, ' ');
+		camel_mime_message_set_subject (message, new_subject->str);
+		g_free (old_subject);
+		g_string_free (new_subject, TRUE);
+	}	
+
 	if (!camel_exchange_store_connected (store, ex)) {
 		camel_exchange_journal_append ((CamelExchangeJournal *) ((CamelExchangeFolder *)folder)->journal, message, info, appended_uid, ex);
 		return;
@@ -983,7 +1009,7 @@ camel_exchange_folder_construct (CamelFolder *folder, CamelStore *parent,
 		short_name = name;
 	camel_folder_construct (folder, parent, name, short_name);
 
-	if (camel_mkdir (folder_dir, S_IRWXU) != 0) {
+	if (e_util_mkdir_hier (folder_dir, S_IRWXU) != 0) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Could not create directory %s: %s"),
 				      folder_dir, g_strerror (errno));
