@@ -2665,6 +2665,12 @@ subscribe_folder (MailStub *stub, const char *folder_name)
 		return;
 	}
 	
+	if (!strcmp (e_folder_get_type_string (folder), "noselect")) {
+		g_object_unref (folder);
+		mail_stub_return_ok (stub);
+		return;
+	}
+	
 	result = exchange_account_add_favorite (mse->account, folder);
 
 	switch (result) {
@@ -2716,8 +2722,8 @@ unsubscribe_folder (MailStub *stub, const char *folder_name)
 	}
 
 	g_object_unref (folder);
-	
-	pub_name = strchr (folder_name, '/');
+
+	pub_name = strrchr (folder_name, '/');
 	path = g_build_filename ("/favorites", pub_name, NULL);
 	folder = exchange_account_get_folder (mse->account, path);
 	if (!folder) {
